//
// CSE 154
// Sample JSON Test code, used in Lecture
//

/*global fetch */
(function(){

  "use strict";

  const URL = "jsontest.php";

  /**
   * Connect the add-entry button with the event handler
   */
  window.addEventListener("load", init);

  /**
   * Function to handle adding an entry to the database.
   */
  function init() {
    id("test-btn").addEventListener("click", getJsonData);
  }

  /**
   * Event handler to get the JSON data.
   */
  function getJsonData() {
    fetch(URL)
      .then(checkStatus)
      .then(JSON.parse)
      .then(loadData)
      .catch(console.error);
  }


  /**
   * Function to load the JSON data into the document
   * @param {object} data - the data that is being returned from the API in JSON format
   *
   */
  function loadData(data) {
    let response = id("response");
    response.innerText = data["name"] + "'s Hobbies";
    let ul = document.createElement("ul");
    response.appendChild(ul);
    for(let i = 0; i < data["hobbies"].length; i++) {
      let li = document.createElement("li");
      li.innerText = data["hobbies"][i];
      ul.appendChild(li);
    }
  }

  /* ------------------------------ Helper Functions  ------------------------------ */
  // Note: You may use these in your code, but do remember that your code should not have
  // any functions defined that are unused.

  /**
   * Returns the element that has the ID attribute with the specified value.
   * @param {string} idName - element ID
   * @returns {object} DOM object associated with id.
   */
  function id(idName) {
    return document.getElementById(idName);
  }

  /**
   * Helper function to return the response's result text if successful, otherwise
   * returns the rejected Promise result with an error status and corresponding text
   * @param {object} response - response to check for success/error
   * @returns {object} - valid result text if response was successful, otherwise rejected
   *                     Promise result
   */
  function checkStatus(response) {
    if (response.status >= 200 && response.status < 300 || response.status === 0) {
      return response.text();
    } else {
      return Promise.reject(new Error(response.status + ": " + response.statusText));
    }
  }

})();
